@@ -12,7 +12,7 @@ Options:
   -v, --version  Print module version and exit.
   --branch=<b>   Branch or tag [default: HEAD] up to which to check.
   --sort=<key>   [default: loc]|commits|files|hours|months.
-  --loc=<type>   surviving|ins(ertions)|del(etions)
+  --loc=<type>   surv(iving)|ins(ertions)|del(etions)
                  What `loc` represents. Use 'ins,del' to count both.
                  defaults to 'surviving' unless `--cost` is specified.
   --excl=<f>     Excluded files (default: None).
@@ -27,26 +27,31 @@ Options:
                    May be multiple comma-separated values.
                    Alters `--loc` default to imply 'ins' (COCOMO) or
                    'ins,del' (hours).
+  -R, --recurse  Recursively find repositories & submodules within <gitdir>.
   -n, --no-regex  Assume <f> are comma-separated exact matches
                   rather than regular expressions [default: False].
                   NB: if regex is enabled ',' is equivalent to '|'.
   -s, --silent-progress    Suppress `tqdm` [default: False].
-  --warn-binary   Don't silently skip files which appear to be binary data
-                  [default: False].
+  --warn-binary  Don't silently skip files which appear to be binary data
+                 [default: False].
   -e, --show-email  Show author email instead of name [default: False].
-  --enum    Show row numbers [default: False].
+  --enum         Show row numbers [default: False].
   -t, --bytype             Show stats per file extension [default: False].
   -w, --ignore-whitespace  Ignore whitespace when comparing the parent's
                            version and the child's to find where the lines
                            came from [default: False].
-  -M  Detect intra-file line moves and copies [default: False].
-  -C  Detect inter-file line moves and copies [default: False].
+  -M             Detect intra-file line moves and copies [default: False].
+  -C             Detect inter-file line moves and copies [default: False].
+  --ignore-rev=<rev>       Ignore changes made by the given revision
+                           (requires `--loc=surviving`).
+  --ignore-revs-file=<f>   Ignore revisions listed in the given file
+                           (requires `--loc=surviving`).
   --format=<format>        Table format
       [default: pipe]|md|markdown|yaml|yml|json|csv|tsv|tabulate.
       May require `git-fame[<format>]`, e.g. `pip install git-fame[yaml]`.
       Any `tabulate.tabulate_formats` is also accepted.
   --manpath=<path>         Directory in which to install git-fame man pages.
-  --log=<lvl>     FATAL|CRITICAL|ERROR|WARN(ING)|[default: INFO]|DEBUG|NOTSET.
+  --log=<lvl>    FATAL|CRITICAL|ERROR|WARN(ING)|[default: INFO]|DEBUG|NOTSET.
 """
 from __future__ import division, print_function
 
@@ -223,7 +228,7 @@ def _get_auth_stats(
         gitdir, branch="HEAD", since=None, include_files=None,
         exclude_files=None, silent_progress=False, ignore_whitespace=False,
         M=False, C=False, warn_binary=False, bytype=False, show_email=False,
-        prefix_gitdir=False, churn=None):
+        prefix_gitdir=False, churn=None, ignore_rev="", ignore_revs_file=None):
   """Returns dict: {"<author>": {"loc": int, "files": {}, "commits": int,
                                  "ctimes": [int]}}"""
   since = ["--since", since] if since else []
@@ -244,6 +249,10 @@ def _get_auth_stats(
 
   if churn & CHURN_SLOC:
     base_cmd = git_cmd + ["blame", "--line-porcelain"] + since
+    if ignore_rev:
+      base_cmd.extend(["--ignore-rev", ignore_rev])
+    if ignore_revs_file:
+      base_cmd.extend(["--ignore-revs-file", ignore_revs_file])
   else:
     base_cmd = git_cmd + ["log", "--format=aN%aN ct%ct", "--numstat"] + since
 
@@ -377,7 +386,28 @@ def run(args):
 
   if isinstance(args.gitdir, string_types):
     args.gitdir = [args.gitdir]
+  # strip `/`, `.git`
   gitdirs = [i.rstrip(os.sep) for i in args.gitdir]
+  gitdirs = [path.join(*path.split(i)[:-1]) if path.split(i)[-1] == '.git' else i
+             for i in args.gitdir]
+  # remove duplicates
+  for i, d in reversed(list(enumerate(gitdirs))):
+    if d in gitdirs[:i]:
+      gitdirs.pop(i)
+  # recurse
+  if args.recurse:
+    nDirs = len(gitdirs)
+    i = 0
+    while i < nDirs:
+      if path.isdir(gitdirs[i]):
+        for root, dirs, fns in tqdm(os.walk(gitdirs[i]), desc="Recursing", unit="dir",
+                                    disable=args.silent_progress, leave=False):
+          if '.git' in fns + dirs:
+            if root not in gitdirs:
+              gitdirs.append(root)
+            if '.git' in dirs:
+              dirs.remove('.git')
+      i += 1
 
   exclude_files = None
   include_files = None
@@ -423,7 +453,8 @@ def run(args):
       ignore_whitespace=args.ignore_whitespace, M=args.M, C=args.C,
       warn_binary=args.warn_binary, bytype=args.bytype,
       show_email=args.show_email, prefix_gitdir=len(gitdirs) > 1,
-      churn=churn)
+      churn=churn, ignore_rev=args.ignore_rev,
+      ignore_revs_file=args.ignore_revs_file)
 
   # concurrent multi-repo processing
   if len(gitdirs) > 1:
